@@ -15,7 +15,7 @@ impl GenericNode<ArithmeticType> for LogarithmNode {
         let right_node = self.right_child.as_ref().ok_or(
             CalculationError::new("The right child of a logarithm node must be present to perform a calculation")
         )?;
-        Ok(left_node.calculate(Some(parameters))?.log(right_node.calculate(Some(parameters))?))
+        Ok(left_node.calculate_wrapped_nodes(parameters)?.log(right_node.calculate_wrapped_nodes(parameters)?))
     }
 }
 
